# Script to set a Windows Server Backup policy for SBS
# Created 27/12/2010
# Assumes: Volumes C:, D: and E: to backup.
#        : Target - \\wss-200\serverbackup
#        : Exclusions - D:\temp, E:\temp
#        : VSS Mode - Full Backup
#        : System State - True
#        : Bare Metal Recovery - True
#        : Schedule - 12:30 PM, 9:00 PM
# ModHist: 27/12/10 - initial
#        : 28/12/10 - Final
#
# Copyright 2010, 2011 by Charlie Russel. All rights reserved. 
#
# With profound thanks to Richard Siddaway, Windows PowerShell MVP
#
# You may copy and modify this script for your own internal use. If you publish this 
# script or a derivative of it in any form you must provide full attribution to the 
# authors of this script, Charlie Russel and Sharon Crawford, and to their book:
# "Windows Small Business Server 2011 Standard Administrator's Companion" (MSPress, 2011)
# for which this script was written. 

Add-PSSnapin Windows.ServerBackup # will error if already loaded, but continue

# First, create a new empty policy
$BackupPolicy = New-WBPolicy

# Now, define the parts of it. 
# First, let's do the volumes. This requires us to first get a list of them, 
# and then parse that list to add the ones we want (C:, D: and E:)
# We don't actually need C:, since we'll get that as part of Bare Metal Restore, 
# but we include it anyway for completeness

$volC = Get-WBVolume -AllVolumes | Where {$_.MountPath -eq "C:"}
$volD = Get-WBVolume -AllVolumes | Where {$_.MountPath -eq "D:"}
$volE = Get-WBVolume -AllVolumes | Where {$_.MountPath -eq "E:"}
$Volumes = $volC,$volD,$volE
# now, add that to the blank policy
Add-WBVolume -policy $BackupPolicy -volume $Volumes

#Define the Exclusions. 
$excD = New-WBFileSpec -Filespec D:\Temp -exclude
$excE = New-WBFileSpec -Filespec E:\Temp -exclude
$FileExclusions = $excE,$excD 
# and then add that to the policy we're building
Add-WBFileSpec -policy $BackupPolicy -filespec $FileExclusions
#Add-WBFileSpec -policy $BackupPolicy -filespec $excE

# Define the backup target
# First, you need to create a credential to connect to the remote share
# You can specify the username here (DOMAIN\User) but will be prompted for password
$Cred = Get-Credential example\Charlie

# Now, define the target
$Target = New-WBBackupTarget -NetworkPath \\WSS-200\ServerBackup -Credential $Cred

# Add the target to the policy
Add-WBBackupTarget -policy $BackupPolicy -target $Target

# Define the schedule
$sch1 = [datetime]"12/27/2010 12:30:00"
$sch2 = [datetime]"12/27/2010 21:00:00"
Set-WBSchedule -policy $BackupPolicy -schedule $sch1,$sch2

# Set for system state and for bare metal recovery
Add-WBSystemState -policy $BackupPolicy
Add-WBBareMetalRecovery -policy $BackupPolicy

# Finally, set for full VSS Backup
Set-WBVssBackupOptions -policy $BackupPolicy -VssFullBackup

# Finally, we need to SET the policy before it actually takes control
Set-WBPolicy -force -policy $BackupPolicy

# This completes the configuration of the SBS server backup policy
$SBSname = (hostname).tolower()
" The SBS Server $SBSname now has the following backup configuration: "
""
Get-WBPolicy 
